part of 'other_improvements_bloc.dart';

class OtherImprovementsState extends Equatable {
  const OtherImprovementsState();

  @override
  List<Object> get props => [];
}

class OtherImprovementsInitial extends OtherImprovementsState {
  @override
  List<Object> get props => [];
}

class OtherImprovementsLoaded extends OtherImprovementsState {
  final List<OtherImprovements> otherImprovements;

  const OtherImprovementsLoaded({required this.otherImprovements});
  @override
  List<Object> get props => [otherImprovements];
}

class LoadSpecificOtherImprovements extends OtherImprovementsState {
  final OtherImprovements otherImprovements;

  const LoadSpecificOtherImprovements({required this.otherImprovements});
  @override
  List<Object> get props => [otherImprovements];
}

class ShowOtherImprovementScreen extends OtherImprovementsState {}

class OtherImprovementsErrorState extends OtherImprovementsState {
  const OtherImprovementsErrorState(this.error);
  final String error;

  @override
  List<Object> get props => [error];
}

class OtherImprovementsDeletedState extends OtherImprovementsState {
  final bool success;
  const OtherImprovementsDeletedState({required this.success});
  @override
  List<Object> get props => [success];
}
